require 'uu/os/form/input'

module UU
  module OS
    module Form

      # Component for choosing icons from catalog.
      class IconPicker < UU::OS::Form::Input

        # Data containing list of icons to choose from. If no data is supplied,
        # icons from uuOS image catalog will be used. The component supports
        # data in the format as returned by catalog-listing commands, such as
        # {UU::ImageCatalog::ImageCatalog#get_image_list} or {UU::OS::ImageCatalog#get_image_list}.
        #
        # @example
        #  # list only arrow icons from uuOS image catalog
        #  iconpicker.data = UU::OS::ImageCatalog.get_image_list(ctx.uu_uri, :query => "code LIKE 'ICON/ARROW%'")
        attr_accessor :data

        # URI of a uuCommand to use for loading data. The data returned from
        # the uuCommand must be in a format supported by {#data data} attribute.
        attr_accessor :data_uri

        # Whether to display input for filtering icons when selecting the icon
        # from a list (in popup or in an inline list).
        # Default value is true.
        attr_accessor :search

        # Whether to display the component in an inline form. When in an inline
        # form, icons are immediately visible in a scrollable list. When not
        # in an inline form, only chosen icon is visible and user must open a popup
        # to display the list of available icons.
        # Default value is false.
        attr_accessor :inline

        # How many rows of icons should be immediately visible in the inline list / popup.
        # If 0 is given, the inline list / popup will stretch itself as high as
        # necessary to display all icons at once.
        # Default value is 4.
        attr_accessor :rows
        
        # Contains JSON with array of categories. Each category must define its own name to display in component and may
        # define list of tags and icon codes. Icons that does not have one of defined tags or its code is not in
        # list of defined codes will be hidden and user cannot select them.
        #
        # @example
        #  # List of categories
        #  icon_picker.category_list = [
        #   { :text => "All icons"},
        #   { :text => "Font icons", :iconTagList => ["FONT_ICON"] },
        #   { :text => "State and font icons", :iconTagList => ["FONT_ICON", "STATE_ICON"] },
        #   { :text => "Arrow icons", :iconList => ["ICON/ARROW_LEFT","ICON/ARROW_UP","ICON/ARROW_RIGHT","ICON/ARROW_DOWN"] } 
        #  ]
        attr_accessor :category_list

        def data
          attributes[:data]
        end

        def data=(value)
          attributes[:data] = value
        end

        def data_uri
          attributes[:dataUri]
        end

        def data_uri=(value)
          attributes[:dataUri] = value
        end

        def search
          attributes[:search]
        end

        def search=(value)
          attributes[:search] = value
        end

        def inline
          attributes[:inline]
        end

        def inline=(value)
          attributes[:inline] = value
        end

        def rows
          attributes[:rows]
        end

        def rows=(value)
          attributes[:rows] = value
        end
        
        def category_list
          attributes[:categoryList]
        end

        def category_list=(value)
          attributes[:categoryList] = value
        end

      end

    end
  end
end
