require 'uu/os/gvc/component'
require 'uu/os/gvc/styleable'

module UU
  module OS
    module GVC

      # Icon component for displaying icons from uuImageCatalog.
      class Icon < UU::OS::GVC::Component
        include UU::OS::GVC::Styleable

        # The width to fit the icon into.
        attr_reader :width

        # The height to fit the icon into.
        attr_reader :height

        # The URI of the catalog icon.
        attr_accessor :icon_uri

        # The tooltip to show when mouse is over the component.
        attr_accessor :tooltip

        # The style for the component. The value can be semicolon separated String
        # containing style rules or a Hash. The style has bigger priority than
        # styling via style_class. Allowed styles:
        #
        # * color - the color of the icon as a hexa value, e.g. '#123456'.
        #
        # @return [Hash] Hash containing style rules (style name as a symbol => style value).
        # @example
        #   icon.style = { :color => '#123456' }
        #   a = icon.style                       # returns { :color => '#123456' }
        #
        #   icon.style = 'color: #ff0000; example: value;'
        #   b = icon.style                       # returns { :color => '#ff0000', :example => 'value' }
        attr_accessor :style

        def width
          attributes[:width]
        end

        def height
          attributes[:height]
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(icon_uri)
          attributes[:iconUri] = icon_uri
        end

        def tooltip
          attributes[:tooltip]
        end

        def tooltip=(tooltip)
          attributes[:tooltip] = tooltip
        end

        def style
          attributes[:style].to_s.split(";").reduce({}) do |h, rule|
            k, v = rule.split(":", 2)
            h[k.strip.to_sym] = v.strip if !v.nil?
            h
          end
        end

        def style=(style)
          value = style
          if (value.kind_of? Hash)
            value = value.keys.map {|k| "#{k}:#{value[k]}"}.join(";")
          end
          attributes[:style] = value
        end

      end

    end
  end
end
