require 'uu/os/gvc/component'

module UU
  module OS
    module GVC

      # Link component.
      class TouchIcon < UU::OS::GVC::Component
        include UU::OS::GVC::Styleable

        # Flag if component is disabled.
        attr_accessor :disabled

        # Touch-icon icon UESURI refers to icon in image catalog.
        attr_accessor :icon_uri

        # Defines target window where the action URI will be opened - one of "CURRENT_WINDOW" (default),
        # "NEW_WINDOW", "DIALOG_WINDOW". For backward compatibility it's also possible to use older equivalents
        # "SELF", "NEW" and "MODAL".
        attr_accessor :target

        # Touch-icon text.
        attr_accessor :text

        # Touch-icon tooltip text.
        attr_accessor :tooltip

        # Touch-icon uri. Can contain valid UESURI or uri to external web page. Web page uris must
        # have one of supported schemas (http, https). External web pages are always opened into
        # new window (attribute target is ignored).
        attr_accessor :action_uri

        def disabled
          attributes[:disabled]
        end

        def disabled=(disabled)
          attributes[:disabled] = disabled
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(icon_uri)
          attributes[:iconUri] = icon_uri
        end

        def target
          attributes[:target]
        end

        def target=(target)
          attributes[:target] = target
        end

        def text
          attributes[:text]
        end

        def text=(text)
          attributes[:text] = text
        end

        def tooltip
          attributes[:tooltip]
        end

        def tooltip=(tooltip)
          attributes[:tooltip] = tooltip
        end

        def action_uri
          attributes[:actionUri]
        end

        def action_uri=(action_uri)
          attributes[:actionUri] = action_uri
        end

      end

    end
  end
end